IPA file is an iOS application archive in `ZIP` format. The IPA file usually contains the following directories:

*   `Payload`: directory containing all application data
*   `iTunesArtwork` and `iTunesArtwork@2x`: iTunes Artwork file containing the application's icon
*   `iTunesMetadata.plist`: file in binary `PLIST` file format describing the application (developpers's name and ID, bundle identifier, name ...)